@@ -59,6 +59,7 @@ protected:
            bool         hurryUp;
            bool         _drain;
            bool         _done;
+           bool         _keepFeeding;
            bool         _endOfStream;
            bool         _setBpp;
            bool         _setFcc;
@@ -115,7 +116,8 @@ public:
       //  virtual uint32_t getSpecificMpeg4Info (void);
         virtual uint8_t getPARWidth (void);
         virtual uint8_t getPARHeight (void);
-        virtual bool decodeErrorHandler(int code, bool headerOnly=false);
+        virtual bool decodeErrorHandler(int code);
+        virtual bool keepFeeding(void) { return _keepFeeding; }
         virtual bool endOfStreamReached(void) { return _endOfStream; }
         virtual void setEndOfStream(bool reached) { _endOfStream=reached; }
         virtual bool getDrainingState(void) { return _drain; }
@@ -148,7 +150,7 @@ FF_SIMPLE_DECLARE(decoderFFhuff,)
 FF_SIMPLE_DECLARE(decoderFF_ffhuff,)
 FF_SIMPLE_DECLARE(decoderFFficv, bool uncompress(ADMCompressedImage *in, ADMImage *out);)
 FF_SIMPLE_DECLARE(decoderFFPng,)
-FF_SIMPLE_DECLARE(decoderFFMpeg4, bool uncompress (ADMCompressedImage * in, ADMImage * out);
+FF_SIMPLE_DECLARE(decoderFFMpeg4, bool uncompress(ADMCompressedImage *in, ADMImage *out);
                                 // mpeg4 can have B-frame
                                 virtual bool bFramePossible (void)   {  return 1;   })
 FF_SIMPLE_DECLARE(decoderFFMpeg12,
